JSONGetTextValue

Enum JSONGetTextValue 

pub enum JSONGetTextValue<'a> {
    Str(&'a str),
    JSONValue(Value),
    JSONValueRef(&'a Value),
}
Represents any valid JSON value. Reference can also be wrapped.

Variants



Str(&'a str)



JSONValue(Value)



JSONValueRef(&'a Value)

Implementations

Source

impl<'a> JSONGetTextValue<'a>

pub fn from_str_ref<S: AsRef<str> + ?Sized>(s: &'a S) -> JSONGetTextValue<'a>

Wrap a borrowed string slice without copying. Use from_string to store an owned string instead.

pub fn from_string<S: Into<String>>(s: S) -> JSONGetTextValue<'static>

pub fn from_json_str<S: AsRef<str>>( s: S, ) -> Result<JSONGetTextValue<'static>, JSONGetTextValueError>

pub fn from_bool(b: bool) -> JSONGetTextValue<'static>

pub fn from_i8(n: i8) -> JSONGetTextValue<'static>

pub fn from_i16(n: i16) -> JSONGetTextValue<'static>

pub fn from_i32(n: i32) -> JSONGetTextValue<'static>

pub fn from_i64(n: i64) -> JSONGetTextValue<'static>

pub fn from_i128( n: i128, ) -> Result<JSONGetTextValue<'static>, JSONGetTextValueError>

pub fn from_isize(n: isize) -> JSONGetTextValue<'static>

pub fn from_u8(n: u8) -> JSONGetTextValue<'static>

pub fn from_u16(n: u16) -> JSONGetTextValue<'static>

pub fn from_u32(n: u32) -> JSONGetTextValue<'static>

pub fn from_u64(n: u64) -> JSONGetTextValue<'static>

pub fn from_u128( n: u128, ) -> Result<JSONGetTextValue<'static>, JSONGetTextValueError>

pub fn from_usize(n: usize) -> JSONGetTextValue<'static>

pub fn from_f32(n: f32) -> JSONGetTextValue<'static>

pub fn from_f64(n: f64) -> JSONGetTextValue<'static>

pub fn from_json_value(v: Value) -> JSONGetTextValue<'static>

pub fn from_json_value_ref(v: &'a Value) -> JSONGetTextValue<'a>

pub fn from_serializable<T: Serialize>( v: T, ) -> Result<JSONGetTextValue<'static>, Error>

pub fn null() -> JSONGetTextValue<'static>

Source

impl<'a> JSONGetTextValue<'a>

pub fn to_json_string(&self) -> String

Convert to a string for JSON format.

pub fn as_str(&self) -> Option<&str>

Convert to a string slice if it is possible (if it is a string).

pub fn as_json_value(&self) -> Option<&Value>

Get the wrapped serde_json::Value if this is not a borrowed string slice.

pub fn as_bool(&self) -> Option<bool>

Get the boolean if it is a boolean.

pub fn as_i64(&self) -> Option<i64>

Get the value as an i64 if it is an integer that fits.

pub fn as_u64(&self) -> Option<u64>

Get the value as a u64 if it is an integer that fits.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64 if it is a number.

pub fn is_null(&self) -> bool

Returns true if this value is JSON null.

pub fn clone_borrowed(&self) -> JSONGetTextValue<'_>

Clone the reference of this JSONGetTextValue instance.

Source

impl<'a> JSONGetTextValue<'a>