pub struct JSONGetTextBuilder<'a> { /* private fields */ }Expand description
To build a JSONGetText instance, this struct can help you do that step by step.
Implementations
Sourceimpl<'a> JSONGetTextBuilder<'a>
impl<'a> JSONGetTextBuilder<'a>
Sourcepub fn new<K: IntoKey>(default_key: K) -> JSONGetTextBuilder<'a>
pub fn new<K: IntoKey>(default_key: K) -> JSONGetTextBuilder<'a>
Create a new JSONGetTextBuilder instance. You need to decide your default key at this stage.
Sourcepub fn allow_extra_texts(&mut self, allow: bool) -> &mut Self
pub fn allow_extra_texts(&mut self, allow: bool) -> &mut Self
Set whether a non-default key may contain texts that the default key does not define.
When enabled, such texts are dropped while building instead of causing a TextInKeyNotInDefaultKey error.
Sourcepub fn add_json<K: IntoKey, J: AsRef<str> + ?Sized>(
&mut self,
key: K,
json: &'a J,
) -> Result<&mut Self, JSONGetTextBuildError>
pub fn add_json<K: IntoKey, J: AsRef<str> + ?Sized>( &mut self, key: K, json: &'a J, ) -> Result<&mut Self, JSONGetTextBuildError>
Add a JSON string to the context for a specific key. The JSON string must represent a map object (key-value).
Sourcepub fn add_json_owned<K: IntoKey, J: AsRef<str>>(
&mut self,
key: K,
json: J,
) -> Result<&mut Self, JSONGetTextBuildError>
pub fn add_json_owned<K: IntoKey, J: AsRef<str>>( &mut self, key: K, json: J, ) -> Result<&mut Self, JSONGetTextBuildError>
Add a JSON string to the context for a specific key. The JSON string must represent a map object (key-value).
Sourcepub fn add_json_file<K: IntoKey, P: AsRef<Path>>(
&mut self,
key: K,
path: P,
) -> Result<&mut Self, JSONGetTextBuildError>
pub fn add_json_file<K: IntoKey, P: AsRef<Path>>( &mut self, key: K, path: P, ) -> Result<&mut Self, JSONGetTextBuildError>
Add a JSON file to the context for a specific key. The JSON file must represent a map object (key-value).
Sourcepub fn add_serialize<K: IntoKey, S: Serialize>(
&mut self,
key: K,
value: S,
) -> Result<&mut Self, JSONGetTextBuildError>
pub fn add_serialize<K: IntoKey, S: Serialize>( &mut self, key: K, value: S, ) -> Result<&mut Self, JSONGetTextBuildError>
Add any serializable value to the context for a specific key. The value must represent a map object (key-value).
Sourcepub fn add_map<K: IntoKey>(
&mut self,
key: K,
map: HashMap<String, JSONGetTextValue<'a>>,
) -> Result<&mut Self, JSONGetTextBuildError>
pub fn add_map<K: IntoKey>( &mut self, key: K, map: HashMap<String, JSONGetTextValue<'a>>, ) -> Result<&mut Self, JSONGetTextBuildError>
Add a map to the context.
Sourcepub fn build(self) -> Result<JSONGetText<'a>, JSONGetTextBuildError>
pub fn build(self) -> Result<JSONGetText<'a>, JSONGetTextBuildError>
Build a JSONGetText instance.