pub struct JSONGetTextManager { /* private fields */ }rocket only.Implementations
Sourceimpl JSONGetTextManager
impl JSONGetTextManager
pub fn from_files( default_key: Key, source: Vec<(Key, &'static str)>, ) -> Result<JSONGetTextManager, JSONGetTextBuildError>
pub fn reload_if_needed(&self) -> Result<(), JSONGetTextBuildError>
Methods from Deref<Target = JSONGetText<'static>>
Sourcepub fn get_default_key(&self) -> Key
Available on crate feature langid only.
pub fn get_default_key(&self) -> Key
langid only.Get the default key.
Sourcepub fn get_keys(&self) -> Vec<Key>
Available on crate feature langid only.
pub fn get_keys(&self) -> Vec<Key>
langid only.Get all keys in context.
Sourcepub fn contains_key<K: LookupKey>(&self, key: K) -> bool
pub fn contains_key<K: LookupKey>(&self, key: K) -> bool
Returns true if the context contains a value for the specified key.
Sourcepub fn get<K: LookupKey>(
&self,
key: K,
) -> &HashMap<String, JSONGetTextValue<'a>>
pub fn get<K: LookupKey>( &self, key: K, ) -> &HashMap<String, JSONGetTextValue<'a>>
Get the texts owned by a key. Missing texts are not filled in from the default key; the default key’s map is returned only when the key itself is absent.
Sourcepub fn get_text<T: AsRef<str>>(&self, text: T) -> Option<JSONGetTextValue<'_>>
pub fn get_text<T: AsRef<str>>(&self, text: T) -> Option<JSONGetTextValue<'_>>
Get text from context.
Sourcepub fn get_text_with_key<K: LookupKey, T: AsRef<str>>(
&self,
key: K,
text: T,
) -> Option<JSONGetTextValue<'_>>
pub fn get_text_with_key<K: LookupKey, T: AsRef<str>>( &self, key: K, text: T, ) -> Option<JSONGetTextValue<'_>>
Get text from context with a specific key, falling back to the default key when the text is missing.
Sourcepub fn get_multiple_text<'b, T: AsRef<str> + ?Sized>(
&self,
text_array: &[&'b T],
) -> Option<BTreeMap<&'b str, JSONGetTextValue<'_>>>
pub fn get_multiple_text<'b, T: AsRef<str> + ?Sized>( &self, text_array: &[&'b T], ) -> Option<BTreeMap<&'b str, JSONGetTextValue<'_>>>
Get multiple text from context. The output map is usually used for serialization.
Sourcepub fn get_multiple_text_with_key<'b, K: LookupKey, T: AsRef<str> + ?Sized>(
&self,
key: K,
text_array: &[&'b T],
) -> Option<BTreeMap<&'b str, JSONGetTextValue<'_>>>
pub fn get_multiple_text_with_key<'b, K: LookupKey, T: AsRef<str> + ?Sized>( &self, key: K, text_array: &[&'b T], ) -> Option<BTreeMap<&'b str, JSONGetTextValue<'_>>>
Get multiple text from context with a specific key, falling back to the default key per text. The output map is usually used for serialization.
Sourcepub fn get_filtered_text(
&self,
regex: &Regex,
) -> Option<BTreeMap<&str, JSONGetTextValue<'_>>>
Available on crate feature regex only.
pub fn get_filtered_text( &self, regex: &Regex, ) -> Option<BTreeMap<&str, JSONGetTextValue<'_>>>
regex only.Get filtered text from context by a Regex instance. The output map is usually used for serialization.
Sourcepub fn get_filtered_text_with_key<K: LookupKey>(
&self,
key: K,
regex: &Regex,
) -> Option<BTreeMap<&str, JSONGetTextValue<'_>>>
Available on crate feature regex only.
pub fn get_filtered_text_with_key<K: LookupKey>( &self, key: K, regex: &Regex, ) -> Option<BTreeMap<&str, JSONGetTextValue<'_>>>
regex only.Get filtered text owned by a specific key by a Regex instance. Texts are not filled in from the default key. The output map is usually used for serialization.