pub trait IntoKey {
// Required method
fn into_key(self) -> Key;
}Expand description
A value that can be turned into a stored Key.
The crate implements this for the enabled key backend, so you rarely implement it yourself.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".